# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.api.agent_api import AgentApi


class TestAgentApi(unittest.TestCase):
    """AgentApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AgentApi()

    def tearDown(self) -> None:
        pass

    def test_enroll(self) -> None:
        """Test case for enroll

        """
        pass

    def test_ping(self) -> None:
        """Test case for ping

        """
        pass

    def test_remote_access(self) -> None:
        """Test case for remote_access

        """
        pass

    def test_remote_share(self) -> None:
        """Test case for remote_share

        """
        pass

    def test_remote_status(self) -> None:
        """Test case for remote_status

        """
        pass

    def test_remote_unaccess(self) -> None:
        """Test case for remote_unaccess

        """
        pass

    def test_remote_unshare(self) -> None:
        """Test case for remote_unshare

        """
        pass

    def test_share_http_healthcheck(self) -> None:
        """Test case for share_http_healthcheck

        """
        pass

    def test_unenroll(self) -> None:
        """Test case for unenroll

        """
        pass


if __name__ == '__main__':
    unittest.main()
