# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.models.remote_status200_response import RemoteStatus200Response

class TestRemoteStatus200Response(unittest.TestCase):
    """RemoteStatus200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RemoteStatus200Response:
        """Test RemoteStatus200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RemoteStatus200Response`
        """
        model = RemoteStatus200Response()
        if include_optional:
            return RemoteStatus200Response(
                shares = [
                    zrok_api.models.remote_status_200_response_shares_inner.remoteStatus_200_response_shares_inner(
                        token = '', 
                        share_mode = '', 
                        backend_mode = '', 
                        reserved = True, 
                        frontend_endpoints = [
                            ''
                            ], 
                        backend_endpoint = '', 
                        open = True, 
                        status = '', )
                    ],
                accesses = [
                    zrok_api.models.remote_status_200_response_accesses_inner.remoteStatus_200_response_accesses_inner(
                        frontend_token = '', 
                        token = '', 
                        bind_address = '', 
                        response_headers = [
                            ''
                            ], )
                    ]
            )
        else:
            return RemoteStatus200Response(
        )
        """

    def testRemoteStatus200Response(self):
        """Test RemoteStatus200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
