# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.api.account_api import AccountApi


class TestAccountApi(unittest.TestCase):
    """AccountApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccountApi()

    def tearDown(self) -> None:
        pass

    def test_change_password(self) -> None:
        """Test case for change_password

        """
        pass

    def test_invite(self) -> None:
        """Test case for invite

        """
        pass

    def test_login(self) -> None:
        """Test case for login

        """
        pass

    def test_regenerate_account_token(self) -> None:
        """Test case for regenerate_account_token

        """
        pass

    def test_register(self) -> None:
        """Test case for register

        """
        pass

    def test_reset_password(self) -> None:
        """Test case for reset_password

        """
        pass

    def test_reset_password_request(self) -> None:
        """Test case for reset_password_request

        """
        pass

    def test_verify(self) -> None:
        """Test case for verify

        """
        pass


if __name__ == '__main__':
    unittest.main()
