# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.models.environment_and_resources import EnvironmentAndResources

class TestEnvironmentAndResources(unittest.TestCase):
    """EnvironmentAndResources unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EnvironmentAndResources:
        """Test EnvironmentAndResources
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EnvironmentAndResources`
        """
        model = EnvironmentAndResources()
        if include_optional:
            return EnvironmentAndResources(
                environment = zrok_api.models.environment.environment(
                    description = '', 
                    host = '', 
                    address = '', 
                    z_id = '', 
                    remote_agent = True, 
                    activity = [
                        zrok_api.models.spark_data_sample.sparkDataSample(
                            rx = 1.337, 
                            tx = 1.337, )
                        ], 
                    limited = True, 
                    created_at = 56, 
                    updated_at = 56, ),
                frontends = [
                    zrok_api.models.frontend.frontend(
                        id = 56, 
                        frontend_token = '', 
                        share_token = '', 
                        backend_mode = '', 
                        bind_address = '', 
                        description = '', 
                        z_id = '', 
                        created_at = 56, 
                        updated_at = 56, )
                    ],
                shares = [
                    zrok_api.models.share.share(
                        share_token = '', 
                        z_id = '', 
                        env_zid = '', 
                        share_mode = '', 
                        backend_mode = '', 
                        frontend_selection = '', 
                        frontend_endpoint = '', 
                        backend_proxy_endpoint = '', 
                        reserved = True, 
                        activity = [
                            zrok_api.models.spark_data_sample.sparkDataSample(
                                rx = 1.337, 
                                tx = 1.337, )
                            ], 
                        limited = True, 
                        created_at = 56, 
                        updated_at = 56, )
                    ]
            )
        else:
            return EnvironmentAndResources(
        )
        """

    def testEnvironmentAndResources(self):
        """Test EnvironmentAndResources"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
