# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.models.get_sparklines200_response import GetSparklines200Response

class TestGetSparklines200Response(unittest.TestCase):
    """GetSparklines200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetSparklines200Response:
        """Test GetSparklines200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetSparklines200Response`
        """
        model = GetSparklines200Response()
        if include_optional:
            return GetSparklines200Response(
                sparklines = [
                    zrok_api.models.metrics.metrics(
                        scope = '', 
                        id = '', 
                        period = 1.337, 
                        samples = [
                            zrok_api.models.metrics_sample.metricsSample(
                                rx = 1.337, 
                                tx = 1.337, 
                                timestamp = 1.337, )
                            ], )
                    ]
            )
        else:
            return GetSparklines200Response(
        )
        """

    def testGetSparklines200Response(self):
        """Test GetSparklines200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
