# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.api.metadata_api import MetadataApi


class TestMetadataApi(unittest.TestCase):
    """MetadataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MetadataApi()

    def tearDown(self) -> None:
        pass

    def test_client_version_check(self) -> None:
        """Test case for client_version_check

        """
        pass

    def test_configuration(self) -> None:
        """Test case for configuration

        """
        pass

    def test_get_account_detail(self) -> None:
        """Test case for get_account_detail

        """
        pass

    def test_get_account_metrics(self) -> None:
        """Test case for get_account_metrics

        """
        pass

    def test_get_environment_detail(self) -> None:
        """Test case for get_environment_detail

        """
        pass

    def test_get_environment_metrics(self) -> None:
        """Test case for get_environment_metrics

        """
        pass

    def test_get_frontend_detail(self) -> None:
        """Test case for get_frontend_detail

        """
        pass

    def test_get_share_detail(self) -> None:
        """Test case for get_share_detail

        """
        pass

    def test_get_share_metrics(self) -> None:
        """Test case for get_share_metrics

        """
        pass

    def test_get_sparklines(self) -> None:
        """Test case for get_sparklines

        """
        pass

    def test_list_memberships(self) -> None:
        """Test case for list_memberships

        """
        pass

    def test_list_org_members(self) -> None:
        """Test case for list_org_members

        """
        pass

    def test_list_public_frontends_for_account(self) -> None:
        """Test case for list_public_frontends_for_account

        """
        pass

    def test_org_account_overview(self) -> None:
        """Test case for org_account_overview

        """
        pass

    def test_overview(self) -> None:
        """Test case for overview

        """
        pass

    def test_version(self) -> None:
        """Test case for version

        """
        pass

    def test_version_inventory(self) -> None:
        """Test case for version_inventory

        """
        pass


if __name__ == '__main__':
    unittest.main()
