# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.models.share_request import ShareRequest

class TestShareRequest(unittest.TestCase):
    """ShareRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShareRequest:
        """Test ShareRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShareRequest`
        """
        model = ShareRequest()
        if include_optional:
            return ShareRequest(
                env_zid = '',
                share_mode = 'public',
                frontend_selection = [
                    ''
                    ],
                backend_mode = 'proxy',
                backend_proxy_endpoint = '',
                auth_scheme = '',
                auth_users = [
                    zrok_api.models.auth_user.authUser(
                        username = '', 
                        password = '', )
                    ],
                oauth_provider = '',
                oauth_email_domains = [
                    ''
                    ],
                oauth_authorization_check_interval = '',
                reserved = True,
                permission_mode = 'open',
                access_grants = [
                    ''
                    ],
                unique_name = ''
            )
        else:
            return ShareRequest(
        )
        """

    def testShareRequest(self):
        """Test ShareRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
