# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.api.environment_api import EnvironmentApi


class TestEnvironmentApi(unittest.TestCase):
    """EnvironmentApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EnvironmentApi()

    def tearDown(self) -> None:
        pass

    def test_disable(self) -> None:
        """Test case for disable

        """
        pass

    def test_enable(self) -> None:
        """Test case for enable

        """
        pass


if __name__ == '__main__':
    unittest.main()
