# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.api.admin_api import AdminApi


class TestAdminApi(unittest.TestCase):
    """AdminApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AdminApi()

    def tearDown(self) -> None:
        pass

    def test_add_frontend_grant(self) -> None:
        """Test case for add_frontend_grant

        """
        pass

    def test_add_organization_member(self) -> None:
        """Test case for add_organization_member

        """
        pass

    def test_create_account(self) -> None:
        """Test case for create_account

        """
        pass

    def test_create_frontend(self) -> None:
        """Test case for create_frontend

        """
        pass

    def test_create_identity(self) -> None:
        """Test case for create_identity

        """
        pass

    def test_create_organization(self) -> None:
        """Test case for create_organization

        """
        pass

    def test_delete_account(self) -> None:
        """Test case for delete_account

        """
        pass

    def test_delete_frontend(self) -> None:
        """Test case for delete_frontend

        """
        pass

    def test_delete_frontend_grant(self) -> None:
        """Test case for delete_frontend_grant

        """
        pass

    def test_delete_identity(self) -> None:
        """Test case for delete_identity

        """
        pass

    def test_delete_organization(self) -> None:
        """Test case for delete_organization

        """
        pass

    def test_grants(self) -> None:
        """Test case for grants

        """
        pass

    def test_invite_token_generate(self) -> None:
        """Test case for invite_token_generate

        """
        pass

    def test_list_frontends(self) -> None:
        """Test case for list_frontends

        """
        pass

    def test_list_organization_members(self) -> None:
        """Test case for list_organization_members

        """
        pass

    def test_list_organizations(self) -> None:
        """Test case for list_organizations

        """
        pass

    def test_remove_organization_member(self) -> None:
        """Test case for remove_organization_member

        """
        pass

    def test_update_frontend(self) -> None:
        """Test case for update_frontend

        """
        pass


if __name__ == '__main__':
    unittest.main()
